@@ -1,5 +1,5 @@
 from .base import Anchor, Link, MdSeq, Paragraph, Raw
-from .containers import Admonition, Code, Tab
+from .containers import Admonition, Code, CodeFile, Tab
 from .docstring import Docstring
 from .file import File
 from .header import *
